#
# spec file for package ghc-conduit-extra
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name conduit-extra
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.7
Release:        1.5
Summary:        Batteries included conduit: adapters for common libraries
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-attoparsec-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-conduit-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-resourcet-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-streaming-commons-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-typed-process-devel
BuildRequires:  ghc-typed-process-prof
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-core-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-base-prof
%endif

%description
The conduit package itself maintains relative small dependencies. The purpose
of this package is to collect commonly used utility functions wrapping other
library dependencies, without depending on heavier-weight dependencies.
The basic idea is that this package should only depend on haskell-platform
packages and conduit.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Jan 20 2025 Peter Simons <psimons@suse.com>
- Update conduit-extra to version 1.3.7.
  [#]# 1.3.7
  * Allow Data.Conduit.Network.Unix on Windows [#518](https://github.com/snoyberg/conduit/pull/518)
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue May 10 2022 Peter Simons <psimons@suse.com>
- Update conduit-extra to version 1.3.6.
  [#]# 1.3.6
  * Add support for `transformers-0.6`
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update conduit-extra to version 1.3.5.
  [#]# 1.3.5
  * Add `createSinkClose`
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Jul  4 2019 psimons@suse.com
- Update conduit-extra to version 1.3.4.
  [#]# 1.3.4
  * Use `MonadUnliftIO`-generalized versions of `withProcess`-style functions now provided by `typed-process`
* Thu Jun 27 2019 psimons@suse.com
- Update conduit-extra to version 1.3.3.
  [#]# 1.3.3
  * Disable buffering in process modules [#402](https://github.com/snoyberg/conduit/issues/402)
* Fri Jun 14 2019 psimons@suse.com
- Update conduit-extra to version 1.3.2.
  [#]# 1.3.2
  * Expose `BuilderInput` and `FlushInput`.
* Wed Mar 13 2019 psimons@suse.com
- Update conduit-extra to version 1.3.1.1.
  [#] ChangeLog for conduit-extra
  [#]# 1.3.1.1
  * Attempt to fix a test suite failure [#385](https://github.com/snoyberg/conduit/issues/385)
* Tue Feb 19 2019 psimons@suse.com
- Update conduit-extra to version 1.3.1.
  [#]# 1.3.1
  * Switched `gzip` to use zlib's default compression level.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update conduit-extra to version 1.3.0.
  * Switch over to unliftio
  * Upgrade to conduit 1.3.0
  * Fix withSinkFileBuilder [#344](https://github.com/snoyberg/conduit/pull/344)
  * Fix typo in implementation of `withProcess_`
  * Added `withLoggedProcess_`
  * Add missing `hClose` to `withSinkFileCautious`
  * `sinkHandleBuilder`, `sinkHandleFlush`, `BuilderInput`, and `FlushInput`
    [#336](https://github.com/snoyberg/conduit/pull/336)
  * `withSinkFileCautious`
  * `Data.Conduit.Process.Typed`
  * `withSourceFile`, `withSinkFile`, and `withSinkFileBuilder`
  * Added the `posOffset` field to the
    `Data.Conduit.Attoparsec.Position` data type
    [#331](https://github.com/snoyberg/conduit/issues/331).
  * Speed up `sinkHandle` by not flushing after every output operation.
    [#322](https://github.com/snoyberg/conduit/issues/322)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon May 22 2017 psimons@suse.com
- Update to version 1.1.16 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 1.1.15 revision 1 with cabal2obs.
* Mon Nov 14 2016 psimons@suse.com
- Update to version 1.1.15 with cabal2obs.
* Mon Sep 26 2016 psimons@suse.com
- Update to version 1.1.13.3 with cabal2obs.
* Sun Jul 17 2016 psimons@suse.com
- Update to version 1.1.13.2 revision 0 with cabal2obs.
* Sun Jul 10 2016 mimi.vx@gmail.com
- update to 1.1.13.2
  * Fix alignment issues on non-X86 archs
* Sun Apr  3 2016 mimi.vx@gmail.com
- update to 1.1.13.1
  * Add sinkStorable and sinkStorableEx
* Thu Mar 31 2016 mimi.vx@gmail.com
- update to 1.1.12.1
  * Add sourceProcessWithStreams
  * Fix accidentally breaking change in sourceProcessWithConsumer type signature
* Mon Mar  7 2016 mimi.vx@gmail.com
- update to 1.1.11
  * withCheckedProcessCleanup
* Wed Feb 17 2016 mimi.vx@gmail.com
- update to 1.1.10.1
  * multiple combinator for Data.Conduit.Zlib
* Mon Feb 15 2016 mimi.vx@gmail.com
- update to 1.1.9.3
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 1.1.9.2
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 1.1.9.1
* Sun May 31 2015 mimi.vx@gmail.com
- update to 1.1.9
  * detectUtf
* Sun May 17 2015 mimi.vx@gmail.com
- update to 1.1.8
  * Adding buffer size to sourceHandleRange [#213](https://github.com/snoyberg/conduit/pull/213)
  * Make Binary.lines O(n) instead of O(n^2) [#209](https://github.com/snoyberg/conduit/pull/209)
* Wed Apr 22 2015 mimi.vx@gmail.com
- initial commit
